@@ -18,9 +18,10 @@ utils::globalVariables(
     "V15",
     "Event_Row_Min",
     "Grade",
-    "Finals_Time",
+    "Finals",
     "School",
     "Name",
+    "Prelims",
     "Prelims_Time",
     "Place",
     "Points",
@@ -50,18 +51,28 @@ utils::globalVariables(
     "First",
     "Last",
     "Last_Name",
-    "Finals_Time_sec",
+    "Finals_sec",
     "New_Place",
     "Finals_Place",
     "DQ",
     "Heat",
     "Heat_Row_Min",
+    "Heat_Lane_String",
     "Exhibition",
     "Time",
     "Lane",
     "Time_Score_String",
+    "Time_Score_Specials_String",
     "Grade_String",
     "Name_String",
+    "Rule_String",
+    "Reaction_String",
+    "Sponsorship_String",
+    "Record_String",
+    "Header_String",
+    "Events_Remaining",
+    "Age_String",
+    "Brit_ID_String",
     "Row_Fill",
     "Row_Numb_2",
     "minimum_row",
@@ -79,6 +90,7 @@ utils::globalVariables(
     "Split_50",
     "Age",
     "Para",
+    "Para_String",
     "typo",
     "replacement",
     "clean",
@@ -97,7 +109,9 @@ utils::globalVariables(
     "Time_Converted_mmss",
     "split_length_omega",
     "Reaction_Time",
-    "Finals_Time_Sec",
+    "Finals_Sec",
+    "Finals_Time",
+    "Score",
     "Split_Total",
     "Indent_Length",
     "Dummy",
@@ -109,6 +123,19 @@ utils::globalVariables(
     "Split_3",
     "Split_4",
     "Heat_Lane",
-    "row_index"
+    "row_index",
+    "Time_sec",
+    "Rank",
+    "Ranks",
+    "values",
+    "ind",
+    "max_entries",
+    "max_ind_entries",
+    "Result_numeric",
+    "Event_Points",
+    "Events_Competed",
+    "Counter",
+    "i",
+    "result_col"
   )
 )
